pub struct ReplayNormalizedRequestOptions {
pub exchange: TardisExchange,
pub symbols: Option<Vec<String>>,
pub from: NaiveDate,
pub to: NaiveDate,
pub data_types: Vec<String>,
pub with_disconnect_messages: Option<bool>,
}Expand description
The options that can be specified for calling Tardis Machine Server’s replay-normalized.
Fields
exchange: TardisExchangeRequested TardisExchange.
symbols: Option<Vec<String>>Optional symbols of requested historical data feed. Use /exchanges/:exchange HTTP API to get allowed symbols for requested exchange.
from: NaiveDateReplay period start date (UTC) in a ISO 8601 format, e.g., 2019-10-01.
to: NaiveDateReplay period start date (UTC) in a ISO 8601 format, e.g., 2019-10-02.
data_types: Vec<String>Array of normalized data types for which real-time data will be provided.
with_disconnect_messages: Option<bool>When set to true, sends also disconnect messages that mark events when real-time WebSocket connection that was used to collect the historical data got disconnected.