pub struct StreamNormalizedRequestOptions {
pub exchange: TardisExchange,
pub symbols: Option<Vec<String>>,
pub data_types: Vec<String>,
pub with_disconnect_messages: Option<bool>,
pub timeout_interval_ms: Option<u64>,
}Expand description
The options that can be specified for calling Tardis Machine Server’s stream-normalized.
Fields
exchange: TardisExchangeRequested TardisExchange.
symbols: Option<Vec<String>>Optional symbols of requested real-time data feed.
data_types: Vec<String>Array of normalized data types for which real-time data will be provided.
with_disconnect_messages: Option<bool>When set to true, sends disconnect messages anytime underlying exchange real-time WebSocket connection(s) gets disconnected.
timeout_interval_ms: Option<u64>Specifies time in milliseconds after which connection to real-time exchanges’ WebSocket API is restarted if no message has been received.